"""
Main interface for support service.

Usage::

    ```python
    import boto3
    from mypy_boto3_support import (
        Client,
        DescribeCasesPaginator,
        DescribeCommunicationsPaginator,
        SupportClient,
    )

    session = boto3.Session()

    client: SupportClient = boto3.client("support")
    session_client: SupportClient = session.client("support")

    describe_cases_paginator: DescribeCasesPaginator = client.get_paginator("describe_cases")
    describe_communications_paginator: DescribeCommunicationsPaginator = client.get_paginator("describe_communications")
    ```
"""
from mypy_boto3_support.client import SupportClient
from mypy_boto3_support.paginator import DescribeCasesPaginator, DescribeCommunicationsPaginator

Client = SupportClient


__all__ = ("Client", "DescribeCasesPaginator", "DescribeCommunicationsPaginator", "SupportClient")



# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
"""
Main interface for support service client

Usage::

    ```python
    import boto3
    from mypy_boto3_support import SupportClient

    client: SupportClient = boto3.client("support")
    ```
"""
import sys
from typing import Any, Dict, List, Type, overload

from botocore.exceptions import ClientError as Boto3ClientError
from botocore.paginate import Paginator as Boto3Paginator

from mypy_boto3_support.paginator import DescribeCasesPaginator, DescribeCommunicationsPaginator
from mypy_boto3_support.type_defs import (
    AddAttachmentsToSetResponseTypeDef,
    AddCommunicationToCaseResponseTypeDef,
    AttachmentTypeDef,
    CreateCaseResponseTypeDef,
    DescribeAttachmentResponseTypeDef,
    DescribeCasesResponseTypeDef,
    DescribeCommunicationsResponseTypeDef,
    DescribeServicesResponseTypeDef,
    DescribeSeverityLevelsResponseTypeDef,
    DescribeTrustedAdvisorCheckRefreshStatusesResponseTypeDef,
    DescribeTrustedAdvisorCheckResultResponseTypeDef,
    DescribeTrustedAdvisorChecksResponseTypeDef,
    DescribeTrustedAdvisorCheckSummariesResponseTypeDef,
    RefreshTrustedAdvisorCheckResponseTypeDef,
    ResolveCaseResponseTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("SupportClient",)


class Exceptions:
    AttachmentIdNotFound: Type[Boto3ClientError]
    AttachmentLimitExceeded: Type[Boto3ClientError]
    AttachmentSetExpired: Type[Boto3ClientError]
    AttachmentSetIdNotFound: Type[Boto3ClientError]
    AttachmentSetSizeLimitExceeded: Type[Boto3ClientError]
    CaseCreationLimitExceeded: Type[Boto3ClientError]
    CaseIdNotFound: Type[Boto3ClientError]
    ClientError: Type[Boto3ClientError]
    DescribeAttachmentLimitExceeded: Type[Boto3ClientError]
    InternalServerError: Type[Boto3ClientError]


class SupportClient:
    """
    [Support.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client)
    """

    exceptions: Exceptions

    def add_attachments_to_set(
        self, attachments: List["AttachmentTypeDef"], attachmentSetId: str = None
    ) -> AddAttachmentsToSetResponseTypeDef:
        """
        [Client.add_attachments_to_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.add_attachments_to_set)
        """

    def add_communication_to_case(
        self,
        communicationBody: str,
        caseId: str = None,
        ccEmailAddresses: List[str] = None,
        attachmentSetId: str = None,
    ) -> AddCommunicationToCaseResponseTypeDef:
        """
        [Client.add_communication_to_case documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.add_communication_to_case)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.can_paginate)
        """

    def create_case(
        self,
        subject: str,
        communicationBody: str,
        serviceCode: str = None,
        severityCode: str = None,
        categoryCode: str = None,
        ccEmailAddresses: List[str] = None,
        language: str = None,
        issueType: str = None,
        attachmentSetId: str = None,
    ) -> CreateCaseResponseTypeDef:
        """
        [Client.create_case documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.create_case)
        """

    def describe_attachment(self, attachmentId: str) -> DescribeAttachmentResponseTypeDef:
        """
        [Client.describe_attachment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.describe_attachment)
        """

    def describe_cases(
        self,
        caseIdList: List[str] = None,
        displayId: str = None,
        afterTime: str = None,
        beforeTime: str = None,
        includeResolvedCases: bool = None,
        nextToken: str = None,
        maxResults: int = None,
        language: str = None,
        includeCommunications: bool = None,
    ) -> DescribeCasesResponseTypeDef:
        """
        [Client.describe_cases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.describe_cases)
        """

    def describe_communications(
        self,
        caseId: str,
        beforeTime: str = None,
        afterTime: str = None,
        nextToken: str = None,
        maxResults: int = None,
    ) -> DescribeCommunicationsResponseTypeDef:
        """
        [Client.describe_communications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.describe_communications)
        """

    def describe_services(
        self, serviceCodeList: List[str] = None, language: str = None
    ) -> DescribeServicesResponseTypeDef:
        """
        [Client.describe_services documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.describe_services)
        """

    def describe_severity_levels(
        self, language: str = None
    ) -> DescribeSeverityLevelsResponseTypeDef:
        """
        [Client.describe_severity_levels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.describe_severity_levels)
        """

    def describe_trusted_advisor_check_refresh_statuses(
        self, checkIds: List[str]
    ) -> DescribeTrustedAdvisorCheckRefreshStatusesResponseTypeDef:
        """
        [Client.describe_trusted_advisor_check_refresh_statuses documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.describe_trusted_advisor_check_refresh_statuses)
        """

    def describe_trusted_advisor_check_result(
        self, checkId: str, language: str = None
    ) -> DescribeTrustedAdvisorCheckResultResponseTypeDef:
        """
        [Client.describe_trusted_advisor_check_result documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.describe_trusted_advisor_check_result)
        """

    def describe_trusted_advisor_check_summaries(
        self, checkIds: List[str]
    ) -> DescribeTrustedAdvisorCheckSummariesResponseTypeDef:
        """
        [Client.describe_trusted_advisor_check_summaries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.describe_trusted_advisor_check_summaries)
        """

    def describe_trusted_advisor_checks(
        self, language: str
    ) -> DescribeTrustedAdvisorChecksResponseTypeDef:
        """
        [Client.describe_trusted_advisor_checks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.describe_trusted_advisor_checks)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.generate_presigned_url)
        """

    def refresh_trusted_advisor_check(
        self, checkId: str
    ) -> RefreshTrustedAdvisorCheckResponseTypeDef:
        """
        [Client.refresh_trusted_advisor_check documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.refresh_trusted_advisor_check)
        """

    def resolve_case(self, caseId: str = None) -> ResolveCaseResponseTypeDef:
        """
        [Client.resolve_case documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Client.resolve_case)
        """

    @overload
    def get_paginator(self, operation_name: Literal["describe_cases"]) -> DescribeCasesPaginator:
        """
        [Paginator.DescribeCases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Paginator.DescribeCases)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["describe_communications"]
    ) -> DescribeCommunicationsPaginator:
        """
        [Paginator.DescribeCommunications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Paginator.DescribeCommunications)
        """

    def get_paginator(self, operation_name: str) -> Boto3Paginator:
        pass



"""
Main interface for support service type definitions.

Usage::

    ```python
    from mypy_boto3_support.type_defs import AttachmentDetailsTypeDef

    data: AttachmentDetailsTypeDef = {...}
    ```
"""
import sys
from typing import List

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "AttachmentDetailsTypeDef",
    "AttachmentTypeDef",
    "CaseDetailsTypeDef",
    "CategoryTypeDef",
    "CommunicationTypeDef",
    "RecentCaseCommunicationsTypeDef",
    "ServiceTypeDef",
    "SeverityLevelTypeDef",
    "TrustedAdvisorCategorySpecificSummaryTypeDef",
    "TrustedAdvisorCheckDescriptionTypeDef",
    "TrustedAdvisorCheckRefreshStatusTypeDef",
    "TrustedAdvisorCheckResultTypeDef",
    "TrustedAdvisorCheckSummaryTypeDef",
    "TrustedAdvisorCostOptimizingSummaryTypeDef",
    "TrustedAdvisorResourceDetailTypeDef",
    "TrustedAdvisorResourcesSummaryTypeDef",
    "AddAttachmentsToSetResponseTypeDef",
    "AddCommunicationToCaseResponseTypeDef",
    "CreateCaseResponseTypeDef",
    "DescribeAttachmentResponseTypeDef",
    "DescribeCasesResponseTypeDef",
    "DescribeCommunicationsResponseTypeDef",
    "DescribeServicesResponseTypeDef",
    "DescribeSeverityLevelsResponseTypeDef",
    "DescribeTrustedAdvisorCheckRefreshStatusesResponseTypeDef",
    "DescribeTrustedAdvisorCheckResultResponseTypeDef",
    "DescribeTrustedAdvisorCheckSummariesResponseTypeDef",
    "DescribeTrustedAdvisorChecksResponseTypeDef",
    "PaginatorConfigTypeDef",
    "RefreshTrustedAdvisorCheckResponseTypeDef",
    "ResolveCaseResponseTypeDef",
)

AttachmentDetailsTypeDef = TypedDict(
    "AttachmentDetailsTypeDef", {"attachmentId": str, "fileName": str}, total=False
)

AttachmentTypeDef = TypedDict("AttachmentTypeDef", {"fileName": str, "data": bytes}, total=False)

CaseDetailsTypeDef = TypedDict(
    "CaseDetailsTypeDef",
    {
        "caseId": str,
        "displayId": str,
        "subject": str,
        "status": str,
        "serviceCode": str,
        "categoryCode": str,
        "severityCode": str,
        "submittedBy": str,
        "timeCreated": str,
        "recentCommunications": "RecentCaseCommunicationsTypeDef",
        "ccEmailAddresses": List[str],
        "language": str,
    },
    total=False,
)

CategoryTypeDef = TypedDict("CategoryTypeDef", {"code": str, "name": str}, total=False)

CommunicationTypeDef = TypedDict(
    "CommunicationTypeDef",
    {
        "caseId": str,
        "body": str,
        "submittedBy": str,
        "timeCreated": str,
        "attachmentSet": List["AttachmentDetailsTypeDef"],
    },
    total=False,
)

RecentCaseCommunicationsTypeDef = TypedDict(
    "RecentCaseCommunicationsTypeDef",
    {"communications": List["CommunicationTypeDef"], "nextToken": str},
    total=False,
)

ServiceTypeDef = TypedDict(
    "ServiceTypeDef", {"code": str, "name": str, "categories": List["CategoryTypeDef"]}, total=False
)

SeverityLevelTypeDef = TypedDict("SeverityLevelTypeDef", {"code": str, "name": str}, total=False)

TrustedAdvisorCategorySpecificSummaryTypeDef = TypedDict(
    "TrustedAdvisorCategorySpecificSummaryTypeDef",
    {"costOptimizing": "TrustedAdvisorCostOptimizingSummaryTypeDef"},
    total=False,
)

TrustedAdvisorCheckDescriptionTypeDef = TypedDict(
    "TrustedAdvisorCheckDescriptionTypeDef",
    {"id": str, "name": str, "description": str, "category": str, "metadata": List[str]},
)

TrustedAdvisorCheckRefreshStatusTypeDef = TypedDict(
    "TrustedAdvisorCheckRefreshStatusTypeDef",
    {"checkId": str, "status": str, "millisUntilNextRefreshable": int},
)

TrustedAdvisorCheckResultTypeDef = TypedDict(
    "TrustedAdvisorCheckResultTypeDef",
    {
        "checkId": str,
        "timestamp": str,
        "status": str,
        "resourcesSummary": "TrustedAdvisorResourcesSummaryTypeDef",
        "categorySpecificSummary": "TrustedAdvisorCategorySpecificSummaryTypeDef",
        "flaggedResources": List["TrustedAdvisorResourceDetailTypeDef"],
    },
)

_RequiredTrustedAdvisorCheckSummaryTypeDef = TypedDict(
    "_RequiredTrustedAdvisorCheckSummaryTypeDef",
    {
        "checkId": str,
        "timestamp": str,
        "status": str,
        "resourcesSummary": "TrustedAdvisorResourcesSummaryTypeDef",
        "categorySpecificSummary": "TrustedAdvisorCategorySpecificSummaryTypeDef",
    },
)
_OptionalTrustedAdvisorCheckSummaryTypeDef = TypedDict(
    "_OptionalTrustedAdvisorCheckSummaryTypeDef", {"hasFlaggedResources": bool}, total=False
)


class TrustedAdvisorCheckSummaryTypeDef(
    _RequiredTrustedAdvisorCheckSummaryTypeDef, _OptionalTrustedAdvisorCheckSummaryTypeDef
):
    pass


TrustedAdvisorCostOptimizingSummaryTypeDef = TypedDict(
    "TrustedAdvisorCostOptimizingSummaryTypeDef",
    {"estimatedMonthlySavings": float, "estimatedPercentMonthlySavings": float},
)

_RequiredTrustedAdvisorResourceDetailTypeDef = TypedDict(
    "_RequiredTrustedAdvisorResourceDetailTypeDef",
    {"status": str, "resourceId": str, "metadata": List[str]},
)
_OptionalTrustedAdvisorResourceDetailTypeDef = TypedDict(
    "_OptionalTrustedAdvisorResourceDetailTypeDef",
    {"region": str, "isSuppressed": bool},
    total=False,
)


class TrustedAdvisorResourceDetailTypeDef(
    _RequiredTrustedAdvisorResourceDetailTypeDef, _OptionalTrustedAdvisorResourceDetailTypeDef
):
    pass


TrustedAdvisorResourcesSummaryTypeDef = TypedDict(
    "TrustedAdvisorResourcesSummaryTypeDef",
    {
        "resourcesProcessed": int,
        "resourcesFlagged": int,
        "resourcesIgnored": int,
        "resourcesSuppressed": int,
    },
)

AddAttachmentsToSetResponseTypeDef = TypedDict(
    "AddAttachmentsToSetResponseTypeDef", {"attachmentSetId": str, "expiryTime": str}, total=False
)

AddCommunicationToCaseResponseTypeDef = TypedDict(
    "AddCommunicationToCaseResponseTypeDef", {"result": bool}, total=False
)

CreateCaseResponseTypeDef = TypedDict("CreateCaseResponseTypeDef", {"caseId": str}, total=False)

DescribeAttachmentResponseTypeDef = TypedDict(
    "DescribeAttachmentResponseTypeDef", {"attachment": "AttachmentTypeDef"}, total=False
)

DescribeCasesResponseTypeDef = TypedDict(
    "DescribeCasesResponseTypeDef",
    {"cases": List["CaseDetailsTypeDef"], "nextToken": str},
    total=False,
)

DescribeCommunicationsResponseTypeDef = TypedDict(
    "DescribeCommunicationsResponseTypeDef",
    {"communications": List["CommunicationTypeDef"], "nextToken": str},
    total=False,
)

DescribeServicesResponseTypeDef = TypedDict(
    "DescribeServicesResponseTypeDef", {"services": List["ServiceTypeDef"]}, total=False
)

DescribeSeverityLevelsResponseTypeDef = TypedDict(
    "DescribeSeverityLevelsResponseTypeDef",
    {"severityLevels": List["SeverityLevelTypeDef"]},
    total=False,
)

DescribeTrustedAdvisorCheckRefreshStatusesResponseTypeDef = TypedDict(
    "DescribeTrustedAdvisorCheckRefreshStatusesResponseTypeDef",
    {"statuses": List["TrustedAdvisorCheckRefreshStatusTypeDef"]},
)

DescribeTrustedAdvisorCheckResultResponseTypeDef = TypedDict(
    "DescribeTrustedAdvisorCheckResultResponseTypeDef",
    {"result": "TrustedAdvisorCheckResultTypeDef"},
    total=False,
)

DescribeTrustedAdvisorCheckSummariesResponseTypeDef = TypedDict(
    "DescribeTrustedAdvisorCheckSummariesResponseTypeDef",
    {"summaries": List["TrustedAdvisorCheckSummaryTypeDef"]},
)

DescribeTrustedAdvisorChecksResponseTypeDef = TypedDict(
    "DescribeTrustedAdvisorChecksResponseTypeDef",
    {"checks": List["TrustedAdvisorCheckDescriptionTypeDef"]},
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
)

RefreshTrustedAdvisorCheckResponseTypeDef = TypedDict(
    "RefreshTrustedAdvisorCheckResponseTypeDef",
    {"status": "TrustedAdvisorCheckRefreshStatusTypeDef"},
)

ResolveCaseResponseTypeDef = TypedDict(
    "ResolveCaseResponseTypeDef", {"initialCaseStatus": str, "finalCaseStatus": str}, total=False
)



# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
"""
Main interface for support service client paginators.

Usage::

    ```python
    import boto3

    from mypy_boto3_support import SupportClient
    from mypy_boto3_support.paginator import (
        DescribeCasesPaginator,
        DescribeCommunicationsPaginator,
    )

    client: SupportClient = boto3.client("support")

    describe_cases_paginator: DescribeCasesPaginator = client.get_paginator("describe_cases")
    describe_communications_paginator: DescribeCommunicationsPaginator = client.get_paginator("describe_communications")
    ```
"""
from typing import Iterator, List

from botocore.paginate import Paginator as Boto3Paginator

from mypy_boto3_support.type_defs import (
    DescribeCasesResponseTypeDef,
    DescribeCommunicationsResponseTypeDef,
    PaginatorConfigTypeDef,
)

__all__ = ("DescribeCasesPaginator", "DescribeCommunicationsPaginator")


class DescribeCasesPaginator(Boto3Paginator):
    """
    [Paginator.DescribeCases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Paginator.DescribeCases)
    """

    def paginate(
        self,
        caseIdList: List[str] = None,
        displayId: str = None,
        afterTime: str = None,
        beforeTime: str = None,
        includeResolvedCases: bool = None,
        language: str = None,
        includeCommunications: bool = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[DescribeCasesResponseTypeDef]:
        """
        [DescribeCases.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Paginator.DescribeCases.paginate)
        """


class DescribeCommunicationsPaginator(Boto3Paginator):
    """
    [Paginator.DescribeCommunications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Paginator.DescribeCommunications)
    """

    def paginate(
        self,
        caseId: str,
        beforeTime: str = None,
        afterTime: str = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[DescribeCommunicationsResponseTypeDef]:
        """
        [DescribeCommunications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/support.html#Support.Paginator.DescribeCommunications.paginate)
        """
